@@ -1,24 +1,16 @@
 =pod
 
-=head1 NAME
-
 Net::OSCAR::Common -- Net::OSCAR public constants
 
-=head1 VERSION
-
-version 1.927_001
-
 =cut
 
 package Net::OSCAR::Common;
-BEGIN {
-  $Net::OSCAR::Common::VERSION = '1.927_001';
-}
 
-$REVISION = '$Revision$';
+$VERSION = '1.925';
+$REVISION = '$Revision: 1.67 $';
 
 use strict;
-use vars qw(@ISA @EXPORT_OK %EXPORT_TAGS);
+use vars qw(@ISA @EXPORT_OK %EXPORT_TAGS $VERSION);
 use Scalar::Util qw(dualvar);
 require Exporter;
 @ISA = qw(Exporter);
@@ -169,11 +161,11 @@ use constant OSCAR_SVC_AIM => (
 	port => 5190,
 	supermajor => 0x0109,
 	major => 5,
-	minor => 9,
+	minor => 5,
 	subminor => 0,
-	build => 0x0E76,
-	subbuild => 0x00000111,
-	clistr => "AOL Instant Messenger, version 5.9.3702/WIN32",
+	build => 0x0E0B,
+	subbuild => 0x00000104,
+	clistr => "AOL Instant Messenger, version 5.5.3595/WIN32",
 	hashlogin => 0,
 	betainfo => "",
 );
@@ -190,4 +182,4 @@ use constant OSCAR_SVC_ICQ => ( # Courtesy of SDiZ Cheng
 	hashlogin => 1,
 );	
 
-1;
\ No newline at end of file
+1;
