@@ -5,18 +5,16 @@ Net::OSCAR::Connection::Chat -- OSCAR chat connections
 =cut
 
 package Net::OSCAR::Connection::Chat;
-BEGIN {
-  $Net::OSCAR::Connection::Chat::VERSION = '1.927_001';
-}
 
-$REVISION = '$Revision$';
+$VERSION = '1.925';
+$REVISION = '$Revision: 1.10 $';
 
 use strict;
 use Carp;
 
 use Net::OSCAR::TLV;
 use Net::OSCAR::Callbacks;
-use vars qw(@ISA);
+use vars qw(@ISA $VERSION);
 use Net::OSCAR::Common qw(:all);
 use Net::OSCAR::Constants;
 use Net::OSCAR::Utility;
