@@ -5,15 +5,13 @@ Net::OSCAR::Connection::Server -- Net::OSCAR server connection
 =cut
 
 package Net::OSCAR::Connection::Server;
-BEGIN {
-  $Net::OSCAR::Connection::Server::VERSION = '1.927_001';
-}
 
-$REVISION = '$Revision$';
+$VERSION = '1.925';
+$REVISION = '$Revision: 1.5 $';
 @ISA = qw(Net::OSCAR::Connection);
 
 use strict;
-use vars qw(@ISA);
+use vars qw($VERSION @ISA);
 use Carp;
 use Socket;
 use Symbol;
