@@ -1,24 +1,16 @@
 =pod
 
-=head1 NAME
-
 Net::OSCAR::Constants -- internal Net::OSCAR constants
 
-=head1 VERSION
-
-version 1.927_001
-
 =cut
 
 package Net::OSCAR::Constants;
-BEGIN {
-  $Net::OSCAR::Constants::VERSION = '1.927_001';
-}
 
-$REVISION = '$Revision$';
+$VERSION = '1.925';
+$REVISION = '$Revision: 1.11 $';
 
 use strict;
-use vars qw(@ISA @EXPORT);
+use vars qw(@ISA @EXPORT $VERSION);
 use Scalar::Util qw(dualvar);
 use Net::OSCAR::TLV;
 require Exporter;
@@ -175,4 +167,4 @@ use constant ICQ_META_INFO => {
 };
 use constant ICQ_META_INFO_INVERSE => { map { ICQ_META_INFO()->{$_} => $_ } keys %{ICQ_META_INFO()} };
 
-1;
\ No newline at end of file
+1;
