@@ -1,29 +1,19 @@
 =pod
 
-=head1 NAME
-
 Net::OSCAR::TLV -- tied hash for OSCAR TLVs
 
-=head1 VERSION
-
-version 1.927_001
-
-=head1 DESCRIPTION
-
 Keys in hashes tied to this class will be treated as numbers.
 This class also preserves the ordering of its keys.
 
 =cut
 
 package Net::OSCAR::TLV;
-BEGIN {
-  $Net::OSCAR::TLV::VERSION = '1.927_001';
-}
 
-$REVISION = '$Revision$';
+$VERSION = '1.925';
+$REVISION = '$Revision: 1.31 $';
 
 use strict;
-use vars qw(@EXPORT @ISA);
+use vars qw($VERSION @EXPORT @ISA);
 
 require Exporter;
 @ISA = qw(Exporter);
@@ -153,4 +143,4 @@ sub tlv(;@) {
 }
 
 
-1;
\ No newline at end of file
+1;
