@@ -1,24 +1,16 @@
 =pod
 
-=head1 NAME
-
 Net::OSCAR::Utility -- internal utility functions for Net::OSCAR
 
-=head1 VERSION
-
-version 1.927_001
-
 =cut
 
 package Net::OSCAR::Utility;
-BEGIN {
-  $Net::OSCAR::Utility::VERSION = '1.927_001';
-}
 
-$REVISION = '$Revision$';
+$VERSION = '1.925';
+$REVISION = '$Revision: 1.29 $';
 
 use strict;
-use vars qw(@ISA @EXPORT);
+use vars qw(@ISA @EXPORT $VERSION);
 use Digest::MD5 qw(md5);
 use Carp;
 
@@ -173,8 +165,7 @@ sub tlv_encode($) {
 	my $tlv = shift;
 	my($buffer, $type, $value) = ("", 0, "");
 
-	confess "You must use a tied Net::OSCAR::TLV hash!" 
-	   unless defined($tlv) and ref($tlv) eq "HASH" and defined(tied(%$tlv)) and tied(%$tlv)->isa("Net::OSCAR::TLV");
+	confess "You must use a tied Net::OSCAR::TLV hash!" unless defined($tlv) and ref($tlv) eq "HASH" and defined(%$tlv) and defined(tied(%$tlv)) and tied(%$tlv)->isa("Net::OSCAR::TLV");
 	while (($type, $value) = each %$tlv) {
 		$value ||= "";
 		$buffer .= pack("nna*", $type, length($value), $value);
@@ -214,7 +205,6 @@ sub signon_tlv($;$$) {
 	} else {
 		if($session->{auth_response}) {
 			$protodata{auth_response} = delete $session->{auth_response};
-			$protodata{pass_is_hashed} = "" if delete $session->{pass_is_hashed};
 		} else {
 			# As of AIM 5.5, the password can be MD5'd before
 			# going into the things-to-cat-together-and-MD5.
@@ -301,4 +291,4 @@ sub hash_iter_reset($) {
 	while((undef, undef) = each(%{$_[0]})) {}
 }
 
-1;
\ No newline at end of file
+1;
