@@ -1,15 +1,7 @@
 =pod
 
-=head1 NAME
-
 Net::OSCAR::XML -- XML functions for Net::OSCAR
 
-=head1 VERSION
-
-version 1.927_001
-
-=head1 DESCRIPTION
-
 We're doing the fancy-schmancy Protocol.xml stuff here, so I'll explain it here.
 
 Protocol.xml contains a number of "OSCAR protocol elements".  One E<lt>defineE<gt> block
@@ -29,14 +21,12 @@ for every protocol element.
 =cut
 
 package Net::OSCAR::XML;
-BEGIN {
-  $Net::OSCAR::XML::VERSION = '1.927_001';
-}
 
-$REVISION = '$Revision$';
+$VERSION = '1.925';
+$REVISION = '$Revision: 1.24 $';
 
 use strict;
-use vars qw(@ISA @EXPORT);
+use vars qw(@ISA @EXPORT $VERSION);
 use Carp;
 use Data::Dumper;
 
@@ -343,4 +333,4 @@ sub snac_to_protobit(%) {
 	}
 }
 
-1;
\ No newline at end of file
+1;
